==> jc-1.4.0.tar.gz: soot/jimple/internal/JVirtualInvokeExpr.h <==
// public class soot.jimple.internal.JVirtualInvokeExpr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a0ee2217a7b698d3 soot_jimple_internal_AbstractInstanceInvokeExpr
// @dep_class 6b76cbc3f8fbbdb7 soot_jimple_internal_AbstractInvokeExpr
// @dep_class 63d0ad00bf9c0eff soot_jimple_internal_AbstractVirtualInvokeExpr
// @dep_class f0157bd42097a65d soot_jimple_internal_JVirtualInvokeExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractVirtualInvokeExpr

#include "soot/jimple/internal/AbstractVirtualInvokeExpr.h"

#ifndef _JC_soot_jimple_internal_JVirtualInvokeExpr_H_
#define _JC_soot_jimple_internal_JVirtualInvokeExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_JVirtualInvokeExpr$sub_refs	_jc_soot_jimple_internal_JVirtualInvokeExpr$sub_refs;
typedef struct _jc_soot_jimple_internal_JVirtualInvokeExpr$sub_nonrefs	_jc_soot_jimple_internal_JVirtualInvokeExpr$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_JVirtualInvokeExpr$refs	_jc_soot_jimple_internal_JVirtualInvokeExpr$refs;
typedef struct _jc_soot_jimple_internal_JVirtualInvokeExpr$nonrefs	_jc_soot_jimple_internal_JVirtualInvokeExpr$nonrefs;
typedef struct _jc_soot_jimple_internal_JVirtualInvokeExpr$object	_jc_soot_jimple_internal_JVirtualInvokeExpr$object;

typedef const struct _jc_soot_jimple_internal_JVirtualInvokeExpr$vmethods	_jc_soot_jimple_internal_JVirtualInvokeExpr$vmethods;
typedef const struct _jc_soot_jimple_internal_JVirtualInvokeExpr$vtable	_jc_soot_jimple_internal_JVirtualInvokeExpr$vtable;
typedef const struct _jc_soot_jimple_internal_JVirtualInvokeExpr$vtype	_jc_soot_jimple_internal_JVirtualInvokeExpr$vtype;

// Constructors
extern void _jc_soot_jimple_internal_JVirtualInvokeExpr$method$_init$737b9105a0ba7cab(_jc_env *, struct _jc_soot_jimple_internal_JVirtualInvokeExpr$object *, struct _jc_object *, struct _jc_soot_SootMethod$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_JVirtualInvokeExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_internal_JVirtualInvokeExpr$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_JVirtualInvokeExpr$method_info$clone$b75f2713d6705f70;

// Virtual methods structure
struct _jc_soot_jimple_internal_JVirtualInvokeExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_internal_JVirtualInvokeExpr$object *);
};

// Vtable
struct _jc_soot_jimple_internal_JVirtualInvokeExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractInvokeExpr$vmethods	soot_jimple_internal_AbstractInvokeExpr;
	_jc_soot_jimple_internal_AbstractInstanceInvokeExpr$vmethods	soot_jimple_internal_AbstractInstanceInvokeExpr;
	_jc_soot_jimple_internal_AbstractVirtualInvokeExpr$vmethods	soot_jimple_internal_AbstractVirtualInvokeExpr;
	_jc_soot_jimple_internal_JVirtualInvokeExpr$vmethods	soot_jimple_internal_JVirtualInvokeExpr;
};

// Vtype
struct _jc_soot_jimple_internal_JVirtualInvokeExpr$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_JVirtualInvokeExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_JVirtualInvokeExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_JVirtualInvokeExpr$refs {
    _jc_soot_jimple_internal_JVirtualInvokeExpr$sub_refs	soot_jimple_internal_JVirtualInvokeExpr;
    _jc_soot_jimple_internal_AbstractVirtualInvokeExpr$sub_refs	soot_jimple_internal_AbstractVirtualInvokeExpr;
    _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$sub_refs	soot_jimple_internal_AbstractInstanceInvokeExpr;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_refs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_JVirtualInvokeExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_JVirtualInvokeExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractInstanceInvokeExpr;
    _jc_soot_jimple_internal_AbstractVirtualInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractVirtualInvokeExpr;
    _jc_soot_jimple_internal_JVirtualInvokeExpr$sub_nonrefs	soot_jimple_internal_JVirtualInvokeExpr;
};

// Object instance structure
struct _jc_soot_jimple_internal_JVirtualInvokeExpr$object {
	_jc_soot_jimple_internal_JVirtualInvokeExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_JVirtualInvokeExpr$vtype	*vtype;
	_jc_soot_jimple_internal_JVirtualInvokeExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_JVirtualInvokeExpr$vtype _jc_soot_jimple_internal_JVirtualInvokeExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_JVirtualInvokeExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_JVirtualInvokeExpr$class_object;

#endif	/* _JC_soot_jimple_internal_JVirtualInvokeExpr_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/internal/JVirtualInvokeExpr.h <==
// public class soot.jimple.internal.JVirtualInvokeExpr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a0ee2217a7b698d3 soot_jimple_internal_AbstractInstanceInvokeExpr
// @dep_class 6b76cbc3f8fbbdb7 soot_jimple_internal_AbstractInvokeExpr
// @dep_class 63d0ad00bf9c0eff soot_jimple_internal_AbstractVirtualInvokeExpr
// @dep_class f0157bd42097a65d soot_jimple_internal_JVirtualInvokeExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractVirtualInvokeExpr

#include "soot/jimple/internal/AbstractVirtualInvokeExpr.h"

#ifndef _JC_soot_jimple_internal_JVirtualInvokeExpr_H_
#define _JC_soot_jimple_internal_JVirtualInvokeExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_JVirtualInvokeExpr$sub_refs	_jc_soot_jimple_internal_JVirtualInvokeExpr$sub_refs;
typedef struct _jc_soot_jimple_internal_JVirtualInvokeExpr$sub_nonrefs	_jc_soot_jimple_internal_JVirtualInvokeExpr$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_JVirtualInvokeExpr$refs	_jc_soot_jimple_internal_JVirtualInvokeExpr$refs;
typedef struct _jc_soot_jimple_internal_JVirtualInvokeExpr$nonrefs	_jc_soot_jimple_internal_JVirtualInvokeExpr$nonrefs;
typedef struct _jc_soot_jimple_internal_JVirtualInvokeExpr$object	_jc_soot_jimple_internal_JVirtualInvokeExpr$object;

typedef const struct _jc_soot_jimple_internal_JVirtualInvokeExpr$vmethods	_jc_soot_jimple_internal_JVirtualInvokeExpr$vmethods;
typedef const struct _jc_soot_jimple_internal_JVirtualInvokeExpr$vtable	_jc_soot_jimple_internal_JVirtualInvokeExpr$vtable;
typedef const struct _jc_soot_jimple_internal_JVirtualInvokeExpr$vtype	_jc_soot_jimple_internal_JVirtualInvokeExpr$vtype;

// Constructors
extern void _jc_soot_jimple_internal_JVirtualInvokeExpr$method$_init$737b9105a0ba7cab(_jc_env *, struct _jc_soot_jimple_internal_JVirtualInvokeExpr$object *, struct _jc_object *, struct _jc_soot_SootMethod$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_JVirtualInvokeExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_internal_JVirtualInvokeExpr$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_JVirtualInvokeExpr$method_info$clone$b75f2713d6705f70;

// Virtual methods structure
struct _jc_soot_jimple_internal_JVirtualInvokeExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_internal_JVirtualInvokeExpr$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_internal_JVirtualInvokeExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractInvokeExpr$vmethods	soot_jimple_internal_AbstractInvokeExpr;
	_jc_soot_jimple_internal_AbstractInstanceInvokeExpr$vmethods	soot_jimple_internal_AbstractInstanceInvokeExpr;
	_jc_soot_jimple_internal_AbstractVirtualInvokeExpr$vmethods	soot_jimple_internal_AbstractVirtualInvokeExpr;
	_jc_soot_jimple_internal_JVirtualInvokeExpr$vmethods	soot_jimple_internal_JVirtualInvokeExpr;
};

// Vtype
struct _jc_soot_jimple_internal_JVirtualInvokeExpr$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_JVirtualInvokeExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_JVirtualInvokeExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_JVirtualInvokeExpr$refs {
    _jc_soot_jimple_internal_JVirtualInvokeExpr$sub_refs	soot_jimple_internal_JVirtualInvokeExpr;
    _jc_soot_jimple_internal_AbstractVirtualInvokeExpr$sub_refs	soot_jimple_internal_AbstractVirtualInvokeExpr;
    _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$sub_refs	soot_jimple_internal_AbstractInstanceInvokeExpr;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_refs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_JVirtualInvokeExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_JVirtualInvokeExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractInstanceInvokeExpr;
    _jc_soot_jimple_internal_AbstractVirtualInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractVirtualInvokeExpr;
    _jc_soot_jimple_internal_JVirtualInvokeExpr$sub_nonrefs	soot_jimple_internal_JVirtualInvokeExpr;
};

// Object instance structure
struct _jc_soot_jimple_internal_JVirtualInvokeExpr$object {
	_jc_soot_jimple_internal_JVirtualInvokeExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_JVirtualInvokeExpr$vtype	*vtype;
	_jc_soot_jimple_internal_JVirtualInvokeExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_JVirtualInvokeExpr$vtype _jc_soot_jimple_internal_JVirtualInvokeExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_JVirtualInvokeExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_JVirtualInvokeExpr$class_object;

#endif	/* _JC_soot_jimple_internal_JVirtualInvokeExpr_H_ */
